OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, selecione um ficheiro.",
    "File is too big" : "O ficheiro é demasiado grande",
    "The selected file is not an image." : "O ficheiro selecionado não é uma imagem.",
    "The selected file cannot be read." : "O ficheiro selecionado não pode ser lido.",
    "Invalid file provided" : "Fornecido ficheiro inválido",
    "No image or file provided" : "Imagem ou ficheiro não fornecido",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Invalid image" : "Imagem inválida",
    "An error occurred. Please contact your admin." : "Ocorreu um erro. Por favor, contacte o seu administrador.",
    "No temporary profile picture available, try again" : "Nenhuma imagem de perfil temporária disponível, tente novamente",
    "No crop data provided" : "Não foram fornecidos dados de recorte",
    "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
    "Crop is not square" : "O recorte não é quadrado",
    "State token does not match" : "O token de estado não corresponde",
    "Password reset is disabled" : "A reposição da senha está desativada",
    "Couldn't reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque a senha é inválida",
    "Couldn't reset password because the token is expired" : "Não foi possível repor a palavra-passe porque a senha expirou",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição porque não existe nenhum endereço de e-mail associado para este utilizador. Por favor, contacte o seu administrador.",
    "%s password reset" : "%s reposição de palavra-passe",
    "Password reset" : "Reposição da senha",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no seguinte botão para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique na seguinte hiperligação para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
    "Reset your password" : "Repor a senha",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
    "Couldn't send reset email. Please make sure your username is correct." : "Não foi possível enviar a mensagem de reposição. Por favor, confirme se o seu nome de utilizador está correto.",
    "Preparing update" : "A preparar a atualização",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, utilize o atualizador de linha de comando porque a atualização automática está desativada em config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: a verificar a tabela %s",
    "Turned on maintenance mode" : "Ativou o modo de manutenção",
    "Turned off maintenance mode" : "Desativou o modo de manutenção",
    "Maintenance mode is kept active" : "O modo de manutenção é mantido ativo",
    "Updating database schema" : "A atualizar o esquema da base de dados",
    "Updated database" : "Base de dados atualizada",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados pode ser atualizado (isto pode demorar algum tempo dependendo do tamanho da base de dados)",
    "Checked database schema update" : "Atualização do esquema da base de dados verificada.",
    "Checking updates of apps" : "A procurar por atualizações das aplicações",
    "Checking for update of app \"%s\" in appstore" : "A procurar por atualizações da aplicação \"%s\" na appstore",
    "Update app \"%s\" from appstore" : "Atualizar app \"%s\" da appstore",
    "Checked for update of app \"%s\" in appstore" : "Actualização pra a aplicação \"%s\" procuradas na loja.",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo, dependendo do tamanho da base de dados)",
    "Checked database schema update for apps" : "Atualização do esquema da base de dados para as aplicações verificada.",
    "Updated \"%1$s\" to %2$s" : "Atualizar \"%1$s\" para %2$s",
    "Set log level to debug" : "Definir nível de registo para depurar",
    "Reset log level" : "Reiniciar nível de registo",
    "Starting code integrity check" : "A iniciar a verificação da integridade do código",
    "Finished code integrity check" : "Terminada a verificação da integridade do código",
    "%s (incompatible)" : "%s (incompatível)",
    "Following apps have been disabled: %s" : "Foram desativadas as seguintes aplicações: %s",
    "Already up to date" : "Já está atualizado",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiros, porque a interface WebDAV parece estar com problemas.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "O seu servidor web não está configurado corretamente para resolver \"{url}\". Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "O seu servidor Web não está configurado corretamente para entregar de ficheiros .woff2. Isto é um problema típico da configuração Ngix. Para o Nextcloud 15 serão necessários ajustes de forma a também permitir a entrega de ficheiros .woff2. Compare a sua configuração Ngix com a configuração recomendada na nossa <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar bem configurado para consultar variáveis do ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor, verifique a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação de instalação ↗</a> para notas de configuração do php e configuração do php do seu servidor, especialmente quando utiliza php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A sua base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "O módulo PHP 'fileinfo' está ausente. Recomendamos vivamente que ative este módulo para obter melhores resultados na detecção de tipo MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "O bloqueio de arquivos transacionais está desativado, isto poderá levar a problemas com condições de corrida. Ative 'filelocking.enabled' no config.php para evitar estes problemas. Consulte a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a> para mais informação.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Se a sua instalação não está instalada na raiz do domínio e usa o sistema cron, podem existir problemas com a geração de URL. Para evitar esses problemas, por favor, defina a opção \"overwrite.cli.url\" no seu ficheiro config.php para o caminho webroot da sua instalação (suggestion: \"{suggestedOverwriteCliURL}\")",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Não foi possível executar o cron job via CLI. Ocorreram os seguintes erros técnicos:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "A última tarefa em background executou em {relativeTime}. Algo parece estar errado.",
    "Check the background job settings" : "Verifique as configurações da tarefa de background",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Este servidor não tem ligação à Internet: Não foi possível detectar vários pontos de extremidade. Isso significa que alguns dos recursos como a montagem de armazenamento externo, notificações sobre actualizações ou instalação de aplicações de terceiros não funcionarão. Pode também não ser possível aceder a  ficheiros remotamente e enviar emails de notificação. Sugerimos que active a ligação à Internet para este servidor se desejar ter todos os recursos.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Nenhuma memória cache foi configurada. Para melhorar o seu desempenho, por favor configure a memcache, se disponível. Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Nenhuma fonte de randomização apropriada foi encontrada pelo PHP, o que é altamente desencorajado por motivos de segurança.  Pode ser encontrada mais informação na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Neste momento está a executar PHP {version}. Aconselhamos actualizar a versão de PHP para tirar partido das <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">actualizações de desempenho e segurança fornecidas pelo PHP Group</a> assim que a sua distribuição as suporte.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Está actualmente a correr PHP 5.6. A versão actual mais alta do Nextcloud é a última suportada no PHP 5.6. Aconselhamos que actualize a versão do PHP para 7.0+ para que possa actualizar para o Nextcloud 14.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "A configuração dos cabeçalhos de reverse proxy está incorrecta, ou está a tentar ao Nextcloud através de um proxy confiável. Se não for o caso, trata-se de um problema de segurança e pode permitir a um atacante fazer spoof do endereço IP visível para a Nextcloud. Mais informações podem ser obtidas na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "A Memcached está configurada como cache distribuida, mas o módulo PHP \"memcache\" instalado está incorrecto. \\OC\\Memcache\\Memcached apenas suporta \"memcached\" e não \"memcache\". Ver em <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki sobre ambos os módulos</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alguns ficheiros não passaram no teste de integridade. Mais informação sobre a resolução deste problema pode ser encontrada na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de ficheiros inválidos...</a> / <a href=\"{rescanEndpoint}\">Analisar novamente ...</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "A OPcache PHP não está devidamente carregada. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Para melhorar a performance recomendamos</a> que a carregue na sua instalação de PHP.",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "A OPcache PHP não está devidamente configurada. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Para melhorar a performance recomendamos</a> que use as seguintes definições no <code>php.ini</code>:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A activação desta função é altamente recomendada.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "O seu PHP não suporta FreeType, podendo resultar em fotos de perfil e interface de definições corrompidos. ",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Índice \"{indexName}\" em falta na tabela \"{tableName}\".",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite é atualmente utilizado como a base de dados de backend. Para instalações maiores recomendamos que mude para uma base de dados de backend diferente.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Isto é particularmente recomendado quando estiver a usar um cliente de desktop para sincronização de ficheiros.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Para migrar para outra base de dados, use a ferramenta de linha de comando: 'occ db:convert-type', ou veja a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "A utilização do fornecedor de mensagens php pré-configurado já não é suportado. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Por favor, atualize as configurações do seu servidor de email<a/>.",
    "The PHP memory limit is below the recommended value of 512MB." : "O limite de memória do PHP está abaixo do valor recomendado de 512MB.",
    "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Os directórios de datos e ficheiros estão provavelmente acessíveis através da Internet. O ficheiro .htaccess não está a funcionar. É altamente recomendado que configure o seu servidor web para que o directório de dados deixa de estar acessível, ou movê-lo para fora da raiz de documentos do servidor web. ",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Isto é um potencial risco de segurança ou privacidade, pelo que recomendamos que ajuste esta opção em conformidade.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Algumas funcionalidades poderão não funcionar correctamente, pelo que recomendamos que ajuste esta opção em conformidade.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Isto é um potencial risco de segurança ou privacidade, pelo que se recomenda que ajuste esta opção em conformidade.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "O cabeçalho HTTP \"{header}\" não está definido como \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". Isto pode revelar informações do endereço de proveniência. Veja a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">Recomendação W3C</a>.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "O cabeçalho HTTP \"Strict-Transport-Security\" não está definido para, pelo menos, \"{segundos}\" segundos. Para segurança melhorada, recomenda-se que active o HSTS tal como descrito em <a href=\"{docUrl}\" rel=\"noreferrer noopener\">dicas de segurança</a>.",
    "Shared" : "Partilhado",
    "Shared with" : "Partilhado com ",
    "Shared by" : "Partilhado por",
    "Choose a password for the public link" : "Escolha a palavra-passe para a hiperligação pública",
    "Choose a password for the public link or press the \"Enter\" key" : "Defina a senha para a hiperligação pública ou prima a tecla \"Enter\"",
    "Copied!" : "Copiado!",
    "Copy link" : "Copiar hiperligação",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Prima ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prima Ctrl-C para copiar.",
    "Copy" : "Copiar",
    "Unable to create a link share" : "Impossível criar a hiperligação de partilha",
    "Unable to toggle this option" : "Impossível comutar esta opção",
    "Resharing is not allowed" : "Não é permitido voltar a partilhar",
    "Link" : "Hiperligação",
    "Hide download" : "Ocultar transferência",
    "Password protection enforced" : "Imposta protecção por palavra-passe",
    "Password protect" : "Proteger com palavra-passe",
    "Password" : "Palavra-passe",
    "Allow editing" : "Permitir edição",
    "Email link to person" : "Enviar hiperligação por mensagem para a pessoa",
    "Send" : "Enviar",
    "Allow upload and editing" : "Permitir enviar e editar",
    "Read only" : "Só de leitura",
    "File drop (upload only)" : "Arrastar ficheiro (apenas envio)",
    "Expiration date enforced" : "Imposta data de expiração",
    "Set expiration date" : "Definir a data de expiração",
    "Expiration" : "Expiração",
    "Expiration date" : "Data de expiração",
    "Note to recipient" : "Nota para o receptor",
    "Unshare" : "Cancelar partilha",
    "Delete share link" : "Apagar hiperligação de partilha",
    "Add another link" : "Adicionar outra hiperligação",
    "Password protection for links is mandatory" : "Protecção por palavra-passe é obrigatória para hiperligações",
    "Share to {name}" : "Partilhar com {name}",
    "Share link" : "Partilhar hiperligação",
    "New share link" : "Nova hiperligação de partilha",
    "Created on {time}" : "Criado em {time}",
    "Password protect by Talk" : "Protegido por palavra-passe por Talk",
    "Could not unshare" : "Não foi possível cancelar a partilha",
    "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
    "Shared with you and {circle} by {owner}" : "Partilhado consigo e com {circle} por {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Partilhado consigo e com a conversação {conversation} por {owner}",
    "Shared with you in a conversation by {owner}" : "Partilhado consigo numa conversação por {owner}",
    "Shared with you by {owner}" : "Partilhado consigo por {owner}",
    "Choose a password for the mail share" : "Escolher senha para a partilha de email",
    "group" : "grupo",
    "remote" : "remoto",
    "remote group" : "grupo remoto",
    "email" : "email",
    "conversation" : "conversação",
    "shared by {sharer}" : "partilhado por {sharer}",
    "Can reshare" : "Pode partilhar de novo",
    "Can edit" : "Pode editar",
    "Can create" : "Pode criar",
    "Can change" : "Pode alterar",
    "Can delete" : "Pode apagar",
    "Access control" : "Controlo de acesso",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} partilhado via hiperligação",
    "Error while sharing" : "Erro ao partilhar",
    "Share details could not be loaded for this item." : "Não foi possível carregar os detalhes de partilha para este item.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Pelo menos {count} caracteres para conclusão automática","At least {count} characters are needed for autocompletion"],
    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista pode estar talvez truncada - por favor refine o termo de pesquisa para ver mais resultados.",
    "No users or groups found for {search}" : "Não foram encontrados nenhuns utilizadores ou grupos para {search}",
    "No users found for {search}" : "Não foram encontrados utilizadores para {search}",
    "An error occurred (\"{message}\"). Please try again" : "Ocorreu um erro (\"{message}\"). Por favor, tente de novo. ",
    "An error occurred. Please try again" : "Ocorreu um erro. Por favor, tente de novo.",
    "Home" : "Início",
    "Work" : "Emprego",
    "Other" : "Outro",
    "{sharee} (remote group)" : "{sharee} (grupo remoto)",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Partilhar",
    "Name or email address..." : "Nome ou endereço de email...",
    "Name or federated cloud ID..." : "Nome ou Id. da nuvem federada...",
    "Name, federated cloud ID or email address..." : "Nome, Id. da nuvem federada ou endereço de e-mail...",
    "Name..." : "Nome...",
    "Error" : "Erro",
    "Error removing share" : "Erro ao remover a partilha",
    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
    "restricted" : "limitado",
    "invisible" : "invisível",
    "({scope})" : "({scope})",
    "Delete" : "Apagar",
    "Rename" : "Renomear",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "Etiquetas não encontradas",
    "unknown text" : "texto desconhecido",
    "Hello world!" : "Olá, mundo!",
    "sunny" : "soalheiro",
    "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
    "Hello {name}" : "Olá {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Resultados da pesquisa<script>alert(1)</script></strong>",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualização está a decorrer. Se deixar esta página o processo pode ser interrompido.",
    "Update to {version}" : "Actualizar para {version}",
    "An error occurred." : "Ocorreu um erro.",
    "Please reload the page." : "Por favor, recarregue a página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">verifique o nosso fórum</a> sobre como resolver este problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, informe este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
    "Continue to Nextcloud" : "Continuar para Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["A actualização foi bem sucedida. A redireccionar para Nextcloud dentro de %n segundos.","A actualização foi bem sucedida. A redireccionar para Nextcloud dentro de %n segundos."],
    "Searching other places" : "A pesquisar noutros lugares",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado encontrado noutras pastas para {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de pesquisa noutra pasta","{count} resultados de pesquisa noutras pastas"],
    "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
    "Please contact your administrator." : "Por favor, contacte o seu administrador.",
    "An internal error occurred." : "Ocorreu um erro interno.",
    "Please try again or contact your administrator." : "Por favor, tente de novo ou contacte o seu administrador.",
    "Username or email" : "Utilizador ou e-mail",
    "Log in" : "Iniciar Sessão",
    "Logging in …" : "A entrar...",
    "User disabled" : "Utilizador desativado",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos múltiplas tentativas falhadas de login do seu IP. Por esse motivo, o seu próximo login será adiado por, até, 30 segundos. ",
    "Reset password" : "Repor palavra-passe",
    "Password can not be changed. Please contact your administrator." : "A palavra-passe não pode ser alterada. Por favor, contacte o seu administrador.",
    "Back to login" : "Voltar à entrada",
    "Forgot password?" : "Senha esquecida?",
    "Settings" : "Definições",
    "Could not load your contacts" : "Não foi possível carregar os seus contactos",
    "Search contacts …" : "Pesquisar contactos ...",
    "No contacts found" : "Não foram encontrados contactos",
    "Show all contacts …" : "Mostrar todos os contactos ...",
    "Loading your contacts …" : "A carregar os seus contactos",
    "Looking for {term} …" : "Procurando por {term} …",
    "No" : "Não",
    "Yes" : "Sim",
    "No files in here" : "Sem ficheiros aqui",
    "New folder" : "Nova pasta",
    "No more subfolders in here" : "Atualmente não há sub-pastas aqui",
    "{newName} already exists" : "{newName} já existe",
    "Choose" : "Escolher",
    "Move" : "Mover",
    "Error loading file picker template: {error}" : "Ocorreu um erro ao carregar o modelo de seleção de ficheiro: {error}",
    "OK" : "Confirmar",
    "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
    "read-only" : "só de leitura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro"],
    "One file conflict" : "Um conflito de ficheiro",
    "New Files" : "Novos Ficheiros",
    "Already existing files" : "Ficheiros já existentes",
    "Which files do you want to keep?" : "Quais os ficheiros que pretende manter?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selecionar ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos selecionados)",
    "({count} selected)" : "({count} selecionados)",
    "Error loading file exists template" : "Ocorreu um erro ao carregar o ficheiro do modelo existente",
    "Pending" : "Pendente",
    "Copy to {folder}" : "Copiar para {folder}",
    "Move to {folder}" : "Mover para {folder}",
    "Saving..." : "A guardar...",
    "Authentication required" : "Autenticação necessária",
    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Falha ao autenticar. Tente outra vez.",
    "seconds ago" : "segundos atrás",
    "Connection to server lost" : "Ligação perdida ao servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos"],
    "New in" : "Novo em",
    "View changelog" : "Ver Registo de alterações",
    "No action available" : "Nenhuma acção disponível",
    "Error fetching contact actions" : "Erro ao obter acções dos contactos",
    "Personal" : "Pessoal",
    "Users" : "Utilizadores",
    "Apps" : "Aplicações",
    "Admin" : "Administração",
    "Help" : "Ajuda",
    "Access forbidden" : "Acesso proibido",
    "File not found" : "Ficheiro não encontrado",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Este documento não pode ser encontrado no servidor. Talvez a partilha tenha sido apagada ou expirado?",
    "Back to %s" : "Voltar a %s",
    "Internal Server Error" : "Erro Interno do Servidor",
    "The server was unable to complete your request." : "O servidor não conseguiu completar o seu pedido.",
    "If this happens again, please send the technical details below to the server administrator." : "Se voltar a  acontecer, por favor envie os detalhes técnicos abaixo ao administrador do servidor.",
    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "Id. do pedido: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensagem: %s",
    "File: %s" : "Ficheiro: %s",
    "Line: %s" : "Linha: %s",
    "Trace" : "Rasto",
    "Security warning" : "Aviso de Segurança",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar correctamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
    "Create an <strong>admin account</strong>" : "Criar uma <strong>conta administrativa</strong>",
    "Username" : "Nome de utilizador",
    "Storage & database" : "Armazenamento e base de dados",
    "Data folder" : "Pasta de dados",
    "Configure the database" : "Configure a base de dados",
    "Only %s is available." : "Só está disponível %s.",
    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
    "Database user" : "Utilizador da base de dados",
    "Database password" : "Palavra-passe da base de dados",
    "Database name" : "Nome da base de dados",
    "Database tablespace" : "Tablespace da base de dados",
    "Database host" : "Anfitrião da base de dados",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
    "Performance warning" : "Aviso de desempenho",
    "Finish setup" : "Terminar configuração",
    "Finishing …" : "A terminar...",
    "Need help?" : "Precisa de ajuda?",
    "See the documentation" : "Consulte a documentação",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer o JavaScript para funcionar corretamente. Por favor, {linkstart}ative o JavaScript{linkend} e recarregue a página.",
    "Get your own free account" : "Obtenha a sua própria conta grátis",
    "Skip to main content" : "Saltar para conteúdo principal",
    "Skip to navigation of app" : "Saltar para navegação da aplicação",
    "More apps" : "Mais apps",
    "More" : "Mais",
    "More apps menu" : "Menu de mais aplicações",
    "Search" : "Procurar",
    "Reset search" : "Repor procura",
    "Contacts" : "Contactos",
    "Contacts menu" : "Menu de contactos",
    "Settings menu" : "Menu de configurações",
    "Confirm your password" : "Confirmar senha",
    "Connect to your account" : "Ligar à sua conta",
    "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
    "App token" : "Token da aplicação",
    "Grant access" : "Conceder acesso",
    "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
    "Account access" : "Acesso a conta",
    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir a %1$s aceder à sua conta conta %2$s. ",
    "New password" : "Nova palavra-passe",
    "New Password" : "Nova Palavra-passe",
    "This share is password-protected" : "Esta partilha é protegida por senha",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Two-factor authentication" : "Autenticação de dois factores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A segurança reforçada foi ativada para a sua conta. Por favor, escolha um segundo factor de autenticação.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar pelo menos um dos métodos de autenticação de dois passos activados. Por favor, contacte o seu administrador.",
    "Use backup code" : "Usar código de cópia de segurança",
    "Cancel log in" : "Cancelar entrada",
    "Error while validating your second factor" : "Erro ao validar o segundo factor",
    "Access through untrusted domain" : "Aceder através de um domínio não confiável",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte o seu administrador. Se é um administrador, edite a definição \"trusted_domains\" no config/config.php como no exemplo em config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mais informação acerca de como configurar pode ser encontrada na %1$sdocumentação%2$s. ",
    "App update required" : "É necessário atualizar a aplicação",
    "%1$s will be updated to version %2$s" : "%1$s irá ser atualizada para a versão %2$s",
    "These apps will be updated:" : "Estas aplicações irão ser atualizadas.",
    "These incompatible apps will be disabled:" : "Estas aplicações incompatíveis irão ser desativadas:",
    "The theme %s has been disabled." : "O tema %s foi desativado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que foi efetuada uma cópia de segurança da base de dados, pasta de configuração e de dados antes de prosseguir.",
    "Start update" : "Iniciar atualização",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos limites com instalações maiores, pode executar o seguinte comando na diretoria de instalação:",
    "Detailed logs" : "Registos detalhados",
    "Update needed" : "É necessário atualizar",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor use o actualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter ajuda, veja a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar a fazer a actualização via interface web arrisco a que o pedido expire e  pode causar a perda de dados, no entanto tenho uma cópia de segurança e sei como restaurar a minha instância em caso de falha. ",
    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco.",
    "Maintenance mode" : "Modo de manutenção",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
    "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
    "Updated \"%s\" to %s" : "Atualizado \"%s\" para %s",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Existiram alguns problemas com a verificação de integridade do código. Mais informação…</a>",
    "Dismiss" : "Dispensar",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A hiperligação para reiniciar a sua palavra-passe foi enviada para o seu e-mail. Se não a receber dentro de um tempo aceitável, verifique as suas pastas de spam/lixo.<br> Se não a encontrar, pergunte ao seu administrador local.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Os seus ficheiros estão encriptados. Não haverá forma de recuperar os dados depois de alterar a senha.<br />Se não tiver a certeza do que fazer, por favor, contacte o administrador antes de continuar. <br />Deseja mesmo continuar?",
    "I know what I'm doing" : "Eu sei o que eu estou a fazer",
    "Sending email …" : "A enviar e-mail ...",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} abaixo da versão {version} está instalado. Por motivos de estabilidade e desempenho, recomendamos que atualize {name} para uma versão mais recente.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom não é legível pelo PHP, o que é altamente desencorajado por motivos de segurança. Pode ser encontrada mais informação na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>.",
    "Copy URL" : "Copiar URL",
    "Enable" : "Ativar",
    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} partilhado via ligação",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (remote)" : "{sharee} (remoto)",
    "{sharee} (email)" : "{sharee} (email)",
    "{sharee} (conversation)" : "{sharee} (conversação)",
    "The specified document has not been found on the server." : "O documento especificado não foi encontrado no servidor.",
    "You can click here to return to %s." : "Pode clicar aqui para voltar para %s.",
    "SQLite will be used as database." : "SQLite será usado como base de dados.",
    "For larger installations we recommend to choose a different database backend." : "Para instalações maiores, nós recomendamos que escolha uma interface da base de dados diferente.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "O uso de SQLite é desencorajado especialmente se estiver a pensar em dar uso ao cliente desktop para sincronizar os seus ficheiros no seu computador.",
    "Wrong password." : "Palavra-passe errada.",
    "Please log in before granting %s access to your %s account." : "Por favor, autentique-se antes de permitir o acesso de %s à sua conta %s.",
    "You are about to grant %s access to your %s account." : "Está prestes a permitir a %s aceder à sua conta %s.",
    "Redirecting …" : "A redirecionar...",
    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Segurança melhorada activada na sua conta. Por favor, autentique-se usando o segundo factor.",
    "Further information how to configure this can be found in the %sdocumentation%s." : "Mais informação acerca de como configurar pode ser encontrada na %sdocumentação%s.",
    "%s will be updated to version %s" : "%s será atualizada para a versão %s.",
    "This page will refresh itself when the %s instance is available again." : "Esta página irá ser atualizada quando a instância %s ficar novamente disponível.",
    "Thank you for your patience." : "Obrigado pela sua paciência."
},
"nplurals=2; plural=(n != 1);");
